AndroidCryptoProvider class

Java cryptography provider in Android.

Constructors

AndroidCryptoProvider({required String name, required double version, required String className, required List<AndroidCryptoService> services})

Properties

className → String
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
services → List<AndroidCryptoService>
final
version → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

add({required String className}) → Future<void>
Adds an Android Crypto Provider.
all() → Future<List<AndroidCryptoProvider>>
Returns all cryptography providers in Android.